@@ -3,7 +3,7 @@ import re
 import copy
 import os
 import shlex
-from .sqlinternal import random_ascii_letters_and_digits
+from .datawrapper import random_ascii_letters_and_digits
 
 
 class SQLMapping(object):
@@ -226,7 +226,7 @@ class SQLMapping(object):
                         for (m_Key, m_Value) in m_Mapping_Contents[1]:              # 内容遍历
                             try:
                                 m_New_SQL = self.ReplaceSQL(m_New_SQL, m_Key, m_Value)
-                            except re.error as ex:
+                            except re.error:
                                 print("[WARNING] Invalid regex pattern in ReplaceSQL. ",
                                       file=self.Console)
                 except re.error as ex:
@@ -698,39 +698,53 @@ def SQLAnalyze(p_SQLCommandPlainText):
             SQLSplitResultsWithComments[m_nPos] = ""
 
     # 解析SQLHints
-    m_SQLHints = []
-    m_SQLHint = {}
+    m_SQLHints = []      # 所有的SQLHint信息，是一个字典的列表
+    m_SQLHint = {}       # SQLHint信息，为Key-Value字典信息
     for m_nPos in range(0, len(SQLSplitResultsWithComments)):
         if len(SQLSplitResults[m_nPos]) == 0:
             # 这里为一个注释信息，解析注释信息中是否包含必要的tag
             for line in SQLSplitResultsWithComments[m_nPos].splitlines():
-                # [Hint]  order           -- SQLCli将会把随后的SQL语句进行排序输出，原程序的输出顺序被忽略
                 # [Hint]  Scenario:XXXX   -- 相关SQL的Scenariox信息，仅仅作为日志信息供查看
-                matchObj = re.search(r"^(\s+)?--(\s+)?\[Hint\](\s+)?order", line,
-                                     re.IGNORECASE | re.DOTALL)
-                if matchObj:
-                    m_SQLHint["Order"] = True
-
-                matchObj = re.search(r"^(\s+)?--(\s+)?\[(\s+)?order(\s+)?\]", line,
-                                     re.IGNORECASE | re.DOTALL)
-                if matchObj:
-                    m_SQLHint["Order"] = True
-
-                matchObj = re.search(r"^(\s+)?--(\s+)?\[Hint\](\s+)?Scenario:(.*)", line,
+                matchObj = re.search(r"^(\s+)?--(\s+)?\[Hint](\s+)?Scenario:(.*)", line,
                                      re.IGNORECASE | re.DOTALL)
                 if matchObj:
                     m_SQLHint["SCENARIO"] = matchObj.group(4)
 
-                matchObj = re.search(r"^(\s+)?--(\s+)?\[(\s+)?Scenario:(.*)\]", line,
+                matchObj = re.search(r"^(\s+)?--(\s+)?\[(\s+)?Scenario:(.*)]", line,
                                      re.IGNORECASE | re.DOTALL)
                 if matchObj:
                     m_SQLHint["SCENARIO"] = matchObj.group(4)
 
-            m_SQLHints.append({})
+                # [Hint]  order           -- SQLCli将会把随后的SQL语句进行排序输出，原程序的输出顺序被忽略
+                matchObj = re.search(r"^(\s+)?--(\s+)?\[Hint](\s+)?order", line,
+                                     re.IGNORECASE | re.DOTALL)
+                if matchObj:
+                    m_SQLHint["Order"] = True
+
+                # [Hint]  LogFilter      -- SQLCli会过滤随后显示的输出信息，对于符合过滤条件的，将会被过滤
+                matchObj = re.search(r"^(\s+)?--(\s+)?\[Hint](\s+)?LogFilter(\s+)(.*)", line,
+                                     re.IGNORECASE | re.DOTALL)
+                if matchObj:
+                    # 可能有多个Filter信息
+                    m_SQLFilter = matchObj.group(5).strip()
+                    if "LogFilter" in m_SQLHint:
+                        m_SQLHint["LogFilter"].append(m_SQLFilter)
+                    else:
+                        m_SQLHint["LogFilter"] = [m_SQLFilter, ]
+
+                # [Hint]  LogMask      -- SQLCli会掩码随后显示的输出信息，对于符合掩码条件的，将会被掩码
+                matchObj = re.search(r"^(\s+)?--(\s+)?\[Hint](\s+)?LogMask(\s+)(.*)", line,
+                                     re.IGNORECASE | re.DOTALL)
+                if matchObj:
+                    m_SQLMask = matchObj.group(5).strip()
+                    if "LogMask" in m_SQLHint:
+                        m_SQLHint["LogMask"].append(m_SQLMask)
+                    else:
+                        m_SQLHint["LogMask"] = [m_SQLMask]
+            m_SQLHints.append({})     # 对于注释信息，所有的SQLHint信息都是空的
         else:
             # 这里是一个可执行SQL信息
             # 将这个SQL之前所有解析注释信息送到SQL的标志中，并同时清空当前的SQL标志信息
             m_SQLHints.append(m_SQLHint)
             m_SQLHint = {}
-
     return not m_bInMultiLineSQL, SQLSplitResults, SQLSplitResultsWithComments, m_SQLHints
